==> elfutils_0.159.orig.tar.bz2: elfutils-0.159/libdw/dwarf_bytesize.c <==
/* Return byte size attribute of DIE.
   Copyright (C) 2003, 2005, 2009 Red Hat, Inc.
   This file is part of elfutils.
   Written by Ulrich Drepper <drepper@redhat.com>, 2003.

   This file is free software; you can redistribute it and/or modify
   it under the terms of either

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at
       your option) any later version

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at
       your option) any later version

   or both in parallel, as here.

   elfutils is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see <http://www.gnu.org/licenses/>.  */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <dwarf.h>
#include "libdwP.h"


int
dwarf_bytesize (die)
     Dwarf_Die *die;
{
  Dwarf_Attribute attr_mem;
  Dwarf_Word value;

  return INTUSE(dwarf_formudata) (INTUSE(dwarf_attr_integrate)
				  (die, DW_AT_byte_size, &attr_mem),
				  &value) == 0 ? (int) value : -1;
}
OLD_VERSION (dwarf_bytesize, ELFUTILS_0.122)
NEW_VERSION (dwarf_bytesize, ELFUTILS_0.143)

==> elfutils_0.183.orig.tar.bz2: elfutils-0.183/libdw/dwarf_bytesize.c <==
/* Return byte size attribute of DIE.
   Copyright (C) 2003, 2005, 2009 Red Hat, Inc.
   This file is part of elfutils.
   Written by Ulrich Drepper <drepper@redhat.com>, 2003.

   This file is free software; you can redistribute it and/or modify
   it under the terms of either

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at
       your option) any later version

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at
       your option) any later version

   or both in parallel, as here.

   elfutils is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see <http://www.gnu.org/licenses/>.  */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <dwarf.h>
#include "libdwP.h"


int
dwarf_bytesize (Dwarf_Die *die)
{
  Dwarf_Attribute attr_mem;
  Dwarf_Word value;

  return INTUSE(dwarf_formudata) (INTUSE(dwarf_attr_integrate)
				  (die, DW_AT_byte_size, &attr_mem),
				  &value) == 0 ? (int) value : -1;
}
OLD_VERSION (dwarf_bytesize, ELFUTILS_0.122)
NEW_VERSION (dwarf_bytesize, ELFUTILS_0.143)
